@@ -38,11 +38,16 @@ from zope.schema._bootstrapfields import TextLine
 from zope.schema._bootstrapinterfaces import ConstraintNotSatisfied
 from zope.schema._bootstrapinterfaces import IBeforeObjectAssignedEvent
 from zope.schema._bootstrapinterfaces import IContextAwareDefaultFactory
+from zope.schema._bootstrapinterfaces import IFromBytes
 from zope.schema._bootstrapinterfaces import IFromUnicode
 from zope.schema._bootstrapinterfaces import IValidatable
 from zope.schema._bootstrapinterfaces import InvalidValue
+from zope.schema._bootstrapinterfaces import LenOutOfBounds
 from zope.schema._bootstrapinterfaces import NotAContainer
+from zope.schema._bootstrapinterfaces import NotAnInterface
 from zope.schema._bootstrapinterfaces import NotAnIterator
+from zope.schema._bootstrapinterfaces import OrderableOutOfBounds
+from zope.schema._bootstrapinterfaces import OutOfBounds
 from zope.schema._bootstrapinterfaces import RequiredMissing
 from zope.schema._bootstrapinterfaces import SchemaNotCorrectlyImplemented
 from zope.schema._bootstrapinterfaces import SchemaNotFullyImplemented
@@ -67,9 +72,13 @@ __all__ = [
     'InvalidId',
     'InvalidURI',
     'InvalidValue',
+    'LenOutOfBounds',
     'NotAContainer',
+    'NotAnInterface',
     'NotAnIterator',
     'NotUnique',
+    'OrderableOutOfBounds',
+    'OutOfBounds',
     'RequiredMissing',
     'SchemaNotCorrectlyImplemented',
     'SchemaNotFullyImplemented',
@@ -84,6 +93,7 @@ __all__ = [
     'WrongContainedType',
     'WrongType',
 
+
     # Interfaces
     'IASCII',
     'IASCIILine',
@@ -109,6 +119,7 @@ __all__ = [
     'IFieldEvent',
     'IFieldUpdatedEvent',
     'IFloat',
+    'IFromBytes',
     'IFromUnicode',
     'IFrozenSet',
     'IId',
@@ -131,6 +142,7 @@ __all__ = [
     'IObject',
     'IOrderable',
     'IPassword',
+    'IPythonIdentifier',
     'IRational',
     'IReal',
     'ISequence',
@@ -405,10 +417,14 @@ class IText(IMinMaxLen, IIterable, IField):
 
 
 # for things which are of the str type on both Python 2 and 3
-if PY3:  # pragma: no cover
-    INativeString = IText
-else:  # pragma: no cover
-    INativeString = IBytes
+class INativeString(IText if PY3 else IBytes):
+    """
+    A field that always contains the native `str` type.
+
+    .. versionchanged:: 4.9.0
+       This is now a distinct type instead of an alias for either `IText`
+       or `IBytes`, depending on the platform.
+    """
 
 
 class IASCII(INativeString):
@@ -435,10 +451,14 @@ class ITextLine(IText):
     """Field containing a unicode string without newlines."""
 
 
-if PY3:  # pragma: no cover
-    INativeStringLine = ITextLine
-else:  # pragma: no cover
-    INativeStringLine = IBytesLine
+class INativeStringLine(ITextLine if PY3 else IBytesLine):
+    """
+    A field that always contains the native `str` type, without any newlines.
+
+    .. versionchanged:: 4.9.0
+       This is now a distinct type instead of an alias for either `ITextLine`
+       or `IBytesLine`, depending on the platform.
+    """
 
 
 class IPassword(ITextLine):
@@ -690,6 +710,14 @@ class IDottedName(INativeStringLine):
         )
 
 
+class IPythonIdentifier(INativeStringLine):
+    """
+    A single Python identifier, such as a  variable name.
+
+    .. versionadded:: 4.9.0
+    """
+
+
 class IChoice(IField):
     """Field whose value is contained in a predefined set
 
